@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Milou Project
- * Copyright (C) 2019 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@broulik.de>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 
@@ -45,19 +31,12 @@ public:
     ~RunnerResultsModel() override;
 
     QString queryString() const;
-    void setQueryString(const QString &queryString);
+    void setQueryString(const QString &queryString, const QString &runner);
     Q_SIGNAL void queryStringChanged(const QString &queryString);
 
     bool querying() const;
     Q_SIGNAL void queryingChanged();
 
-    QString runner() const;
-    void setRunner(const QString &runner);
-    Q_SIGNAL void runnerChanged();
-
-    QString runnerName() const;
-    QIcon runnerIcon() const;
-
     /**
      * Clears the model content and resets the runner context, i.e. no new items will appear.
      */
@@ -93,7 +72,7 @@ private:
     QString m_queryString;
     bool m_querying = false;
 
-    QString m_runner;
+    QString m_prevRunner;
 
     QTimer m_resetTimer;
     bool m_hasMatches = false;
